@@ -25,5 +25,5 @@ ENCMAP = {
 
 
 add_map("radio", ENCMAP, sep=" ", ignore_case="both",
-        pattern=r"^(?:military|nato|radio)(?:(?:[-_]phonetic)?(?:[-_]alphabet)?)?$")
+        pattern=r"^(?:military|nato|radio)(?:(?:[-_]phonetic)?(?:[-_]alphabet)?)?$", printables_rate=1.)
 
