@@ -24,5 +24,5 @@ for i in range(256):
         ENCMAP[c] = "%{:02X}".format(i)
 
 
-add_map("url", ENCMAP, ignore_case="decode", no_error=True, pattern=r"^url(?:encode)?$")
+add_map("url", ENCMAP, ignore_case="decode", no_error=True, pattern=r"^url(?:encode)?$", printables_rate=1.)
 
